OC.L10N.register(
    "external",
    {
    "Please enter valid urls - they have to start with either http://, https:// or /" : "올바른 URL을 입력하십시오. http://, http://, /로 시작하여야 합니다",
    "External sites saved." : "외부 사이트를 저장했습니다.",
    "External Sites" : "외부 사이트",
    "Please note that some browsers will block displaying of sites via http if you are running https." : "일부 웹 브라우저에서는 HTTPS로 접속한 사이트 내에서 HTTP 사이트를 표시하는 것을 거부할 수도 있습니다.",
    "Furthermore please note that many sites these days disallow iframing due to security reasons." : "또한 많은 웹 사이트에서 보안상의 이유로 iframe 사용을 금지하고 있습니다.",
    "We highly recommend to test the configured sites below properly." : "아래에 설정된 사이트가 잘 표시되는지 시험해 보는 것을 추천합니다.",
    "Name" : "이름",
    "URL" : "URL",
    "Select an icon" : "아이콘 선택",
    "Remove site" : "사이트 삭제",
    "Add" : "추가"
},
"nplurals=1; plural=0;");
